@@ -112,6 +112,11 @@ gotoblas_t TABLE_NAME = {
 #else
   NULL,NULL,
 #endif
+#ifdef SMALL_MATRIX_OPT
+  sbgemm_small_matrix_permit_PILEDRIVER,
+  sbgemm_small_kernel_nn_PILEDRIVER, sbgemm_small_kernel_nt_PILEDRIVER, sbgemm_small_kernel_tn_PILEDRIVER, sbgemm_small_kernel_tt_PILEDRIVER,
+  sbgemm_small_kernel_b0_nn_PILEDRIVER, sbgemm_small_kernel_b0_nt_PILEDRIVER, sbgemm_small_kernel_b0_tn_PILEDRIVER, sbgemm_small_kernel_b0_tt_PILEDRIVER,
+#endif
 #endif
 
 #if ( BUILD_SINGLE==1) || (BUILD_DOUBLE==1) || (BUILD_COMPLEX==1) || (BUILD_COMPLEX16==1)
@@ -171,6 +176,14 @@ gotoblas_t TABLE_NAME = {
   sgemm_oncopy_PILEDRIVER, sgemm_otcopy_PILEDRIVER,
 #endif
 
+#if BUILD_SINGLE == 1
+#ifdef SMALL_MATRIX_OPT
+  sgemm_small_matrix_permit_PILEDRIVER,
+  sgemm_small_kernel_nn_PILEDRIVER, sgemm_small_kernel_nt_PILEDRIVER, sgemm_small_kernel_tn_PILEDRIVER, sgemm_small_kernel_tt_PILEDRIVER,
+  sgemm_small_kernel_b0_nn_PILEDRIVER, sgemm_small_kernel_b0_nt_PILEDRIVER, sgemm_small_kernel_b0_tn_PILEDRIVER, sgemm_small_kernel_b0_tt_PILEDRIVER,
+#endif
+#endif
+
 #if (BUILD_SINGLE==1) || (BUILD_DOUBLE==1) 
   strsm_kernel_LN_PILEDRIVER, strsm_kernel_LT_PILEDRIVER, strsm_kernel_RN_PILEDRIVER, strsm_kernel_RT_PILEDRIVER,
 #if SGEMM_DEFAULT_UNROLL_M != SGEMM_DEFAULT_UNROLL_N
@@ -257,6 +270,11 @@ gotoblas_t TABLE_NAME = {
 #endif
 
 #if  (BUILD_DOUBLE==1)  
+#ifdef SMALL_MATRIX_OPT
+  dgemm_small_matrix_permit_PILEDRIVER,
+  dgemm_small_kernel_nn_PILEDRIVER, dgemm_small_kernel_nt_PILEDRIVER, dgemm_small_kernel_tn_PILEDRIVER, dgemm_small_kernel_tt_PILEDRIVER,
+  dgemm_small_kernel_b0_nn_PILEDRIVER, dgemm_small_kernel_b0_nt_PILEDRIVER, dgemm_small_kernel_b0_tn_PILEDRIVER, dgemm_small_kernel_b0_tt_PILEDRIVER,
+#endif
   dtrsm_kernel_LN_PILEDRIVER, dtrsm_kernel_LT_PILEDRIVER, dtrsm_kernel_RN_PILEDRIVER, dtrsm_kernel_RT_PILEDRIVER,
 #if DGEMM_DEFAULT_UNROLL_M != DGEMM_DEFAULT_UNROLL_N
   dtrsm_iunucopy_PILEDRIVER, dtrsm_iunncopy_PILEDRIVER, dtrsm_iutucopy_PILEDRIVER, dtrsm_iutncopy_PILEDRIVER,
@@ -389,6 +407,18 @@ gotoblas_t TABLE_NAME = {
 #endif
   cgemm_oncopy_PILEDRIVER, cgemm_otcopy_PILEDRIVER,
 
+#ifdef SMALL_MATRIX_OPT
+  cgemm_small_matrix_permit_PILEDRIVER,
+  cgemm_small_kernel_nn_PILEDRIVER, cgemm_small_kernel_nt_PILEDRIVER, cgemm_small_kernel_nr_PILEDRIVER, cgemm_small_kernel_nc_PILEDRIVER,
+  cgemm_small_kernel_tn_PILEDRIVER, cgemm_small_kernel_tt_PILEDRIVER, cgemm_small_kernel_tr_PILEDRIVER, cgemm_small_kernel_tc_PILEDRIVER,
+  cgemm_small_kernel_rn_PILEDRIVER, cgemm_small_kernel_rt_PILEDRIVER, cgemm_small_kernel_rr_PILEDRIVER, cgemm_small_kernel_rc_PILEDRIVER,
+  cgemm_small_kernel_cn_PILEDRIVER, cgemm_small_kernel_ct_PILEDRIVER, cgemm_small_kernel_cr_PILEDRIVER, cgemm_small_kernel_cc_PILEDRIVER,
+  cgemm_small_kernel_b0_nn_PILEDRIVER, cgemm_small_kernel_b0_nt_PILEDRIVER, cgemm_small_kernel_b0_nr_PILEDRIVER, cgemm_small_kernel_b0_nc_PILEDRIVER,
+  cgemm_small_kernel_b0_tn_PILEDRIVER, cgemm_small_kernel_b0_tt_PILEDRIVER, cgemm_small_kernel_b0_tr_PILEDRIVER, cgemm_small_kernel_b0_tc_PILEDRIVER,
+  cgemm_small_kernel_b0_rn_PILEDRIVER, cgemm_small_kernel_b0_rt_PILEDRIVER, cgemm_small_kernel_b0_rr_PILEDRIVER, cgemm_small_kernel_b0_rc_PILEDRIVER,
+  cgemm_small_kernel_b0_cn_PILEDRIVER, cgemm_small_kernel_b0_ct_PILEDRIVER, cgemm_small_kernel_b0_cr_PILEDRIVER, cgemm_small_kernel_b0_cc_PILEDRIVER,
+#endif
+
   ctrsm_kernel_LN_PILEDRIVER, ctrsm_kernel_LT_PILEDRIVER, ctrsm_kernel_LR_PILEDRIVER, ctrsm_kernel_LC_PILEDRIVER,
   ctrsm_kernel_RN_PILEDRIVER, ctrsm_kernel_RT_PILEDRIVER, ctrsm_kernel_RR_PILEDRIVER, ctrsm_kernel_RC_PILEDRIVER,
 
@@ -533,6 +563,18 @@ gotoblas_t TABLE_NAME = {
 #endif
   zgemm_oncopy_PILEDRIVER, zgemm_otcopy_PILEDRIVER,
 
+#ifdef SMALL_MATRIX_OPT
+  zgemm_small_matrix_permit_PILEDRIVER,
+  zgemm_small_kernel_nn_PILEDRIVER, zgemm_small_kernel_nt_PILEDRIVER, zgemm_small_kernel_nr_PILEDRIVER, zgemm_small_kernel_nc_PILEDRIVER,
+  zgemm_small_kernel_tn_PILEDRIVER, zgemm_small_kernel_tt_PILEDRIVER, zgemm_small_kernel_tr_PILEDRIVER, zgemm_small_kernel_tc_PILEDRIVER,
+  zgemm_small_kernel_rn_PILEDRIVER, zgemm_small_kernel_rt_PILEDRIVER, zgemm_small_kernel_rr_PILEDRIVER, zgemm_small_kernel_rc_PILEDRIVER,
+  zgemm_small_kernel_cn_PILEDRIVER, zgemm_small_kernel_ct_PILEDRIVER, zgemm_small_kernel_cr_PILEDRIVER, zgemm_small_kernel_cc_PILEDRIVER,
+  zgemm_small_kernel_b0_nn_PILEDRIVER, zgemm_small_kernel_b0_nt_PILEDRIVER, zgemm_small_kernel_b0_nr_PILEDRIVER, zgemm_small_kernel_b0_nc_PILEDRIVER,
+  zgemm_small_kernel_b0_tn_PILEDRIVER, zgemm_small_kernel_b0_tt_PILEDRIVER, zgemm_small_kernel_b0_tr_PILEDRIVER, zgemm_small_kernel_b0_tc_PILEDRIVER,
+  zgemm_small_kernel_b0_rn_PILEDRIVER, zgemm_small_kernel_b0_rt_PILEDRIVER, zgemm_small_kernel_b0_rr_PILEDRIVER, zgemm_small_kernel_b0_rc_PILEDRIVER,
+  zgemm_small_kernel_b0_cn_PILEDRIVER, zgemm_small_kernel_b0_ct_PILEDRIVER, zgemm_small_kernel_b0_cr_PILEDRIVER, zgemm_small_kernel_b0_cc_PILEDRIVER,
+#endif
+
   ztrsm_kernel_LN_PILEDRIVER, ztrsm_kernel_LT_PILEDRIVER, ztrsm_kernel_LR_PILEDRIVER, ztrsm_kernel_LC_PILEDRIVER,
   ztrsm_kernel_RN_PILEDRIVER, ztrsm_kernel_RT_PILEDRIVER, ztrsm_kernel_RR_PILEDRIVER, ztrsm_kernel_RC_PILEDRIVER,
 
