@@ -112,6 +112,11 @@ gotoblas_t TABLE_NAME = {
 #else
   NULL,NULL,
 #endif
+#ifdef SMALL_MATRIX_OPT
+  sbgemm_small_matrix_permit_PRESCOTT,
+  sbgemm_small_kernel_nn_PRESCOTT, sbgemm_small_kernel_nt_PRESCOTT, sbgemm_small_kernel_tn_PRESCOTT, sbgemm_small_kernel_tt_PRESCOTT,
+  sbgemm_small_kernel_b0_nn_PRESCOTT, sbgemm_small_kernel_b0_nt_PRESCOTT, sbgemm_small_kernel_b0_tn_PRESCOTT, sbgemm_small_kernel_b0_tt_PRESCOTT,
+#endif
 #endif
 
 #if ( BUILD_SINGLE==1) || (BUILD_DOUBLE==1) || (BUILD_COMPLEX==1) || (BUILD_COMPLEX16==1)
@@ -171,6 +176,14 @@ gotoblas_t TABLE_NAME = {
   sgemm_oncopy_PRESCOTT, sgemm_otcopy_PRESCOTT,
 #endif
 
+#if BUILD_SINGLE == 1
+#ifdef SMALL_MATRIX_OPT
+  sgemm_small_matrix_permit_PRESCOTT,
+  sgemm_small_kernel_nn_PRESCOTT, sgemm_small_kernel_nt_PRESCOTT, sgemm_small_kernel_tn_PRESCOTT, sgemm_small_kernel_tt_PRESCOTT,
+  sgemm_small_kernel_b0_nn_PRESCOTT, sgemm_small_kernel_b0_nt_PRESCOTT, sgemm_small_kernel_b0_tn_PRESCOTT, sgemm_small_kernel_b0_tt_PRESCOTT,
+#endif
+#endif
+
 #if (BUILD_SINGLE==1) || (BUILD_DOUBLE==1) 
   strsm_kernel_LN_PRESCOTT, strsm_kernel_LT_PRESCOTT, strsm_kernel_RN_PRESCOTT, strsm_kernel_RT_PRESCOTT,
 #if SGEMM_DEFAULT_UNROLL_M != SGEMM_DEFAULT_UNROLL_N
@@ -257,6 +270,11 @@ gotoblas_t TABLE_NAME = {
 #endif
 
 #if  (BUILD_DOUBLE==1)  
+#ifdef SMALL_MATRIX_OPT
+  dgemm_small_matrix_permit_PRESCOTT,
+  dgemm_small_kernel_nn_PRESCOTT, dgemm_small_kernel_nt_PRESCOTT, dgemm_small_kernel_tn_PRESCOTT, dgemm_small_kernel_tt_PRESCOTT,
+  dgemm_small_kernel_b0_nn_PRESCOTT, dgemm_small_kernel_b0_nt_PRESCOTT, dgemm_small_kernel_b0_tn_PRESCOTT, dgemm_small_kernel_b0_tt_PRESCOTT,
+#endif
   dtrsm_kernel_LN_PRESCOTT, dtrsm_kernel_LT_PRESCOTT, dtrsm_kernel_RN_PRESCOTT, dtrsm_kernel_RT_PRESCOTT,
 #if DGEMM_DEFAULT_UNROLL_M != DGEMM_DEFAULT_UNROLL_N
   dtrsm_iunucopy_PRESCOTT, dtrsm_iunncopy_PRESCOTT, dtrsm_iutucopy_PRESCOTT, dtrsm_iutncopy_PRESCOTT,
@@ -389,6 +407,18 @@ gotoblas_t TABLE_NAME = {
 #endif
   cgemm_oncopy_PRESCOTT, cgemm_otcopy_PRESCOTT,
 
+#ifdef SMALL_MATRIX_OPT
+  cgemm_small_matrix_permit_PRESCOTT,
+  cgemm_small_kernel_nn_PRESCOTT, cgemm_small_kernel_nt_PRESCOTT, cgemm_small_kernel_nr_PRESCOTT, cgemm_small_kernel_nc_PRESCOTT,
+  cgemm_small_kernel_tn_PRESCOTT, cgemm_small_kernel_tt_PRESCOTT, cgemm_small_kernel_tr_PRESCOTT, cgemm_small_kernel_tc_PRESCOTT,
+  cgemm_small_kernel_rn_PRESCOTT, cgemm_small_kernel_rt_PRESCOTT, cgemm_small_kernel_rr_PRESCOTT, cgemm_small_kernel_rc_PRESCOTT,
+  cgemm_small_kernel_cn_PRESCOTT, cgemm_small_kernel_ct_PRESCOTT, cgemm_small_kernel_cr_PRESCOTT, cgemm_small_kernel_cc_PRESCOTT,
+  cgemm_small_kernel_b0_nn_PRESCOTT, cgemm_small_kernel_b0_nt_PRESCOTT, cgemm_small_kernel_b0_nr_PRESCOTT, cgemm_small_kernel_b0_nc_PRESCOTT,
+  cgemm_small_kernel_b0_tn_PRESCOTT, cgemm_small_kernel_b0_tt_PRESCOTT, cgemm_small_kernel_b0_tr_PRESCOTT, cgemm_small_kernel_b0_tc_PRESCOTT,
+  cgemm_small_kernel_b0_rn_PRESCOTT, cgemm_small_kernel_b0_rt_PRESCOTT, cgemm_small_kernel_b0_rr_PRESCOTT, cgemm_small_kernel_b0_rc_PRESCOTT,
+  cgemm_small_kernel_b0_cn_PRESCOTT, cgemm_small_kernel_b0_ct_PRESCOTT, cgemm_small_kernel_b0_cr_PRESCOTT, cgemm_small_kernel_b0_cc_PRESCOTT,
+#endif
+
   ctrsm_kernel_LN_PRESCOTT, ctrsm_kernel_LT_PRESCOTT, ctrsm_kernel_LR_PRESCOTT, ctrsm_kernel_LC_PRESCOTT,
   ctrsm_kernel_RN_PRESCOTT, ctrsm_kernel_RT_PRESCOTT, ctrsm_kernel_RR_PRESCOTT, ctrsm_kernel_RC_PRESCOTT,
 
@@ -533,6 +563,18 @@ gotoblas_t TABLE_NAME = {
 #endif
   zgemm_oncopy_PRESCOTT, zgemm_otcopy_PRESCOTT,
 
+#ifdef SMALL_MATRIX_OPT
+  zgemm_small_matrix_permit_PRESCOTT,
+  zgemm_small_kernel_nn_PRESCOTT, zgemm_small_kernel_nt_PRESCOTT, zgemm_small_kernel_nr_PRESCOTT, zgemm_small_kernel_nc_PRESCOTT,
+  zgemm_small_kernel_tn_PRESCOTT, zgemm_small_kernel_tt_PRESCOTT, zgemm_small_kernel_tr_PRESCOTT, zgemm_small_kernel_tc_PRESCOTT,
+  zgemm_small_kernel_rn_PRESCOTT, zgemm_small_kernel_rt_PRESCOTT, zgemm_small_kernel_rr_PRESCOTT, zgemm_small_kernel_rc_PRESCOTT,
+  zgemm_small_kernel_cn_PRESCOTT, zgemm_small_kernel_ct_PRESCOTT, zgemm_small_kernel_cr_PRESCOTT, zgemm_small_kernel_cc_PRESCOTT,
+  zgemm_small_kernel_b0_nn_PRESCOTT, zgemm_small_kernel_b0_nt_PRESCOTT, zgemm_small_kernel_b0_nr_PRESCOTT, zgemm_small_kernel_b0_nc_PRESCOTT,
+  zgemm_small_kernel_b0_tn_PRESCOTT, zgemm_small_kernel_b0_tt_PRESCOTT, zgemm_small_kernel_b0_tr_PRESCOTT, zgemm_small_kernel_b0_tc_PRESCOTT,
+  zgemm_small_kernel_b0_rn_PRESCOTT, zgemm_small_kernel_b0_rt_PRESCOTT, zgemm_small_kernel_b0_rr_PRESCOTT, zgemm_small_kernel_b0_rc_PRESCOTT,
+  zgemm_small_kernel_b0_cn_PRESCOTT, zgemm_small_kernel_b0_ct_PRESCOTT, zgemm_small_kernel_b0_cr_PRESCOTT, zgemm_small_kernel_b0_cc_PRESCOTT,
+#endif
+
   ztrsm_kernel_LN_PRESCOTT, ztrsm_kernel_LT_PRESCOTT, ztrsm_kernel_LR_PRESCOTT, ztrsm_kernel_LC_PRESCOTT,
   ztrsm_kernel_RN_PRESCOTT, ztrsm_kernel_RT_PRESCOTT, ztrsm_kernel_RR_PRESCOTT, ztrsm_kernel_RC_PRESCOTT,
 
