@@ -112,6 +112,11 @@ gotoblas_t TABLE_NAME = {
 #else
   NULL,NULL,
 #endif
+#ifdef SMALL_MATRIX_OPT
+  sbgemm_small_matrix_permit_SANDYBRIDGE,
+  sbgemm_small_kernel_nn_SANDYBRIDGE, sbgemm_small_kernel_nt_SANDYBRIDGE, sbgemm_small_kernel_tn_SANDYBRIDGE, sbgemm_small_kernel_tt_SANDYBRIDGE,
+  sbgemm_small_kernel_b0_nn_SANDYBRIDGE, sbgemm_small_kernel_b0_nt_SANDYBRIDGE, sbgemm_small_kernel_b0_tn_SANDYBRIDGE, sbgemm_small_kernel_b0_tt_SANDYBRIDGE,
+#endif
 #endif
 
 #if ( BUILD_SINGLE==1) || (BUILD_DOUBLE==1) || (BUILD_COMPLEX==1) || (BUILD_COMPLEX16==1)
@@ -171,6 +176,14 @@ gotoblas_t TABLE_NAME = {
   sgemm_oncopy_SANDYBRIDGE, sgemm_otcopy_SANDYBRIDGE,
 #endif
 
+#if BUILD_SINGLE == 1
+#ifdef SMALL_MATRIX_OPT
+  sgemm_small_matrix_permit_SANDYBRIDGE,
+  sgemm_small_kernel_nn_SANDYBRIDGE, sgemm_small_kernel_nt_SANDYBRIDGE, sgemm_small_kernel_tn_SANDYBRIDGE, sgemm_small_kernel_tt_SANDYBRIDGE,
+  sgemm_small_kernel_b0_nn_SANDYBRIDGE, sgemm_small_kernel_b0_nt_SANDYBRIDGE, sgemm_small_kernel_b0_tn_SANDYBRIDGE, sgemm_small_kernel_b0_tt_SANDYBRIDGE,
+#endif
+#endif
+
 #if (BUILD_SINGLE==1) || (BUILD_DOUBLE==1) 
   strsm_kernel_LN_SANDYBRIDGE, strsm_kernel_LT_SANDYBRIDGE, strsm_kernel_RN_SANDYBRIDGE, strsm_kernel_RT_SANDYBRIDGE,
 #if SGEMM_DEFAULT_UNROLL_M != SGEMM_DEFAULT_UNROLL_N
@@ -257,6 +270,11 @@ gotoblas_t TABLE_NAME = {
 #endif
 
 #if  (BUILD_DOUBLE==1)  
+#ifdef SMALL_MATRIX_OPT
+  dgemm_small_matrix_permit_SANDYBRIDGE,
+  dgemm_small_kernel_nn_SANDYBRIDGE, dgemm_small_kernel_nt_SANDYBRIDGE, dgemm_small_kernel_tn_SANDYBRIDGE, dgemm_small_kernel_tt_SANDYBRIDGE,
+  dgemm_small_kernel_b0_nn_SANDYBRIDGE, dgemm_small_kernel_b0_nt_SANDYBRIDGE, dgemm_small_kernel_b0_tn_SANDYBRIDGE, dgemm_small_kernel_b0_tt_SANDYBRIDGE,
+#endif
   dtrsm_kernel_LN_SANDYBRIDGE, dtrsm_kernel_LT_SANDYBRIDGE, dtrsm_kernel_RN_SANDYBRIDGE, dtrsm_kernel_RT_SANDYBRIDGE,
 #if DGEMM_DEFAULT_UNROLL_M != DGEMM_DEFAULT_UNROLL_N
   dtrsm_iunucopy_SANDYBRIDGE, dtrsm_iunncopy_SANDYBRIDGE, dtrsm_iutucopy_SANDYBRIDGE, dtrsm_iutncopy_SANDYBRIDGE,
@@ -389,6 +407,18 @@ gotoblas_t TABLE_NAME = {
 #endif
   cgemm_oncopy_SANDYBRIDGE, cgemm_otcopy_SANDYBRIDGE,
 
+#ifdef SMALL_MATRIX_OPT
+  cgemm_small_matrix_permit_SANDYBRIDGE,
+  cgemm_small_kernel_nn_SANDYBRIDGE, cgemm_small_kernel_nt_SANDYBRIDGE, cgemm_small_kernel_nr_SANDYBRIDGE, cgemm_small_kernel_nc_SANDYBRIDGE,
+  cgemm_small_kernel_tn_SANDYBRIDGE, cgemm_small_kernel_tt_SANDYBRIDGE, cgemm_small_kernel_tr_SANDYBRIDGE, cgemm_small_kernel_tc_SANDYBRIDGE,
+  cgemm_small_kernel_rn_SANDYBRIDGE, cgemm_small_kernel_rt_SANDYBRIDGE, cgemm_small_kernel_rr_SANDYBRIDGE, cgemm_small_kernel_rc_SANDYBRIDGE,
+  cgemm_small_kernel_cn_SANDYBRIDGE, cgemm_small_kernel_ct_SANDYBRIDGE, cgemm_small_kernel_cr_SANDYBRIDGE, cgemm_small_kernel_cc_SANDYBRIDGE,
+  cgemm_small_kernel_b0_nn_SANDYBRIDGE, cgemm_small_kernel_b0_nt_SANDYBRIDGE, cgemm_small_kernel_b0_nr_SANDYBRIDGE, cgemm_small_kernel_b0_nc_SANDYBRIDGE,
+  cgemm_small_kernel_b0_tn_SANDYBRIDGE, cgemm_small_kernel_b0_tt_SANDYBRIDGE, cgemm_small_kernel_b0_tr_SANDYBRIDGE, cgemm_small_kernel_b0_tc_SANDYBRIDGE,
+  cgemm_small_kernel_b0_rn_SANDYBRIDGE, cgemm_small_kernel_b0_rt_SANDYBRIDGE, cgemm_small_kernel_b0_rr_SANDYBRIDGE, cgemm_small_kernel_b0_rc_SANDYBRIDGE,
+  cgemm_small_kernel_b0_cn_SANDYBRIDGE, cgemm_small_kernel_b0_ct_SANDYBRIDGE, cgemm_small_kernel_b0_cr_SANDYBRIDGE, cgemm_small_kernel_b0_cc_SANDYBRIDGE,
+#endif
+
   ctrsm_kernel_LN_SANDYBRIDGE, ctrsm_kernel_LT_SANDYBRIDGE, ctrsm_kernel_LR_SANDYBRIDGE, ctrsm_kernel_LC_SANDYBRIDGE,
   ctrsm_kernel_RN_SANDYBRIDGE, ctrsm_kernel_RT_SANDYBRIDGE, ctrsm_kernel_RR_SANDYBRIDGE, ctrsm_kernel_RC_SANDYBRIDGE,
 
@@ -533,6 +563,18 @@ gotoblas_t TABLE_NAME = {
 #endif
   zgemm_oncopy_SANDYBRIDGE, zgemm_otcopy_SANDYBRIDGE,
 
+#ifdef SMALL_MATRIX_OPT
+  zgemm_small_matrix_permit_SANDYBRIDGE,
+  zgemm_small_kernel_nn_SANDYBRIDGE, zgemm_small_kernel_nt_SANDYBRIDGE, zgemm_small_kernel_nr_SANDYBRIDGE, zgemm_small_kernel_nc_SANDYBRIDGE,
+  zgemm_small_kernel_tn_SANDYBRIDGE, zgemm_small_kernel_tt_SANDYBRIDGE, zgemm_small_kernel_tr_SANDYBRIDGE, zgemm_small_kernel_tc_SANDYBRIDGE,
+  zgemm_small_kernel_rn_SANDYBRIDGE, zgemm_small_kernel_rt_SANDYBRIDGE, zgemm_small_kernel_rr_SANDYBRIDGE, zgemm_small_kernel_rc_SANDYBRIDGE,
+  zgemm_small_kernel_cn_SANDYBRIDGE, zgemm_small_kernel_ct_SANDYBRIDGE, zgemm_small_kernel_cr_SANDYBRIDGE, zgemm_small_kernel_cc_SANDYBRIDGE,
+  zgemm_small_kernel_b0_nn_SANDYBRIDGE, zgemm_small_kernel_b0_nt_SANDYBRIDGE, zgemm_small_kernel_b0_nr_SANDYBRIDGE, zgemm_small_kernel_b0_nc_SANDYBRIDGE,
+  zgemm_small_kernel_b0_tn_SANDYBRIDGE, zgemm_small_kernel_b0_tt_SANDYBRIDGE, zgemm_small_kernel_b0_tr_SANDYBRIDGE, zgemm_small_kernel_b0_tc_SANDYBRIDGE,
+  zgemm_small_kernel_b0_rn_SANDYBRIDGE, zgemm_small_kernel_b0_rt_SANDYBRIDGE, zgemm_small_kernel_b0_rr_SANDYBRIDGE, zgemm_small_kernel_b0_rc_SANDYBRIDGE,
+  zgemm_small_kernel_b0_cn_SANDYBRIDGE, zgemm_small_kernel_b0_ct_SANDYBRIDGE, zgemm_small_kernel_b0_cr_SANDYBRIDGE, zgemm_small_kernel_b0_cc_SANDYBRIDGE,
+#endif
+
   ztrsm_kernel_LN_SANDYBRIDGE, ztrsm_kernel_LT_SANDYBRIDGE, ztrsm_kernel_LR_SANDYBRIDGE, ztrsm_kernel_LC_SANDYBRIDGE,
   ztrsm_kernel_RN_SANDYBRIDGE, ztrsm_kernel_RT_SANDYBRIDGE, ztrsm_kernel_RR_SANDYBRIDGE, ztrsm_kernel_RC_SANDYBRIDGE,
 
