@@ -112,6 +112,11 @@ gotoblas_t TABLE_NAME = {
 #else
   NULL,NULL,
 #endif
+#ifdef SMALL_MATRIX_OPT
+  sbgemm_small_matrix_permit_SKYLAKEX,
+  sbgemm_small_kernel_nn_SKYLAKEX, sbgemm_small_kernel_nt_SKYLAKEX, sbgemm_small_kernel_tn_SKYLAKEX, sbgemm_small_kernel_tt_SKYLAKEX,
+  sbgemm_small_kernel_b0_nn_SKYLAKEX, sbgemm_small_kernel_b0_nt_SKYLAKEX, sbgemm_small_kernel_b0_tn_SKYLAKEX, sbgemm_small_kernel_b0_tt_SKYLAKEX,
+#endif
 #endif
 
 #if ( BUILD_SINGLE==1) || (BUILD_DOUBLE==1) || (BUILD_COMPLEX==1) || (BUILD_COMPLEX16==1)
@@ -171,6 +176,14 @@ gotoblas_t TABLE_NAME = {
   sgemm_oncopy_SKYLAKEX, sgemm_otcopy_SKYLAKEX,
 #endif
 
+#if BUILD_SINGLE == 1
+#ifdef SMALL_MATRIX_OPT
+  sgemm_small_matrix_permit_SKYLAKEX,
+  sgemm_small_kernel_nn_SKYLAKEX, sgemm_small_kernel_nt_SKYLAKEX, sgemm_small_kernel_tn_SKYLAKEX, sgemm_small_kernel_tt_SKYLAKEX,
+  sgemm_small_kernel_b0_nn_SKYLAKEX, sgemm_small_kernel_b0_nt_SKYLAKEX, sgemm_small_kernel_b0_tn_SKYLAKEX, sgemm_small_kernel_b0_tt_SKYLAKEX,
+#endif
+#endif
+
 #if (BUILD_SINGLE==1) || (BUILD_DOUBLE==1) 
   strsm_kernel_LN_SKYLAKEX, strsm_kernel_LT_SKYLAKEX, strsm_kernel_RN_SKYLAKEX, strsm_kernel_RT_SKYLAKEX,
 #if SGEMM_DEFAULT_UNROLL_M != SGEMM_DEFAULT_UNROLL_N
@@ -257,6 +270,11 @@ gotoblas_t TABLE_NAME = {
 #endif
 
 #if  (BUILD_DOUBLE==1)  
+#ifdef SMALL_MATRIX_OPT
+  dgemm_small_matrix_permit_SKYLAKEX,
+  dgemm_small_kernel_nn_SKYLAKEX, dgemm_small_kernel_nt_SKYLAKEX, dgemm_small_kernel_tn_SKYLAKEX, dgemm_small_kernel_tt_SKYLAKEX,
+  dgemm_small_kernel_b0_nn_SKYLAKEX, dgemm_small_kernel_b0_nt_SKYLAKEX, dgemm_small_kernel_b0_tn_SKYLAKEX, dgemm_small_kernel_b0_tt_SKYLAKEX,
+#endif
   dtrsm_kernel_LN_SKYLAKEX, dtrsm_kernel_LT_SKYLAKEX, dtrsm_kernel_RN_SKYLAKEX, dtrsm_kernel_RT_SKYLAKEX,
 #if DGEMM_DEFAULT_UNROLL_M != DGEMM_DEFAULT_UNROLL_N
   dtrsm_iunucopy_SKYLAKEX, dtrsm_iunncopy_SKYLAKEX, dtrsm_iutucopy_SKYLAKEX, dtrsm_iutncopy_SKYLAKEX,
@@ -389,6 +407,18 @@ gotoblas_t TABLE_NAME = {
 #endif
   cgemm_oncopy_SKYLAKEX, cgemm_otcopy_SKYLAKEX,
 
+#ifdef SMALL_MATRIX_OPT
+  cgemm_small_matrix_permit_SKYLAKEX,
+  cgemm_small_kernel_nn_SKYLAKEX, cgemm_small_kernel_nt_SKYLAKEX, cgemm_small_kernel_nr_SKYLAKEX, cgemm_small_kernel_nc_SKYLAKEX,
+  cgemm_small_kernel_tn_SKYLAKEX, cgemm_small_kernel_tt_SKYLAKEX, cgemm_small_kernel_tr_SKYLAKEX, cgemm_small_kernel_tc_SKYLAKEX,
+  cgemm_small_kernel_rn_SKYLAKEX, cgemm_small_kernel_rt_SKYLAKEX, cgemm_small_kernel_rr_SKYLAKEX, cgemm_small_kernel_rc_SKYLAKEX,
+  cgemm_small_kernel_cn_SKYLAKEX, cgemm_small_kernel_ct_SKYLAKEX, cgemm_small_kernel_cr_SKYLAKEX, cgemm_small_kernel_cc_SKYLAKEX,
+  cgemm_small_kernel_b0_nn_SKYLAKEX, cgemm_small_kernel_b0_nt_SKYLAKEX, cgemm_small_kernel_b0_nr_SKYLAKEX, cgemm_small_kernel_b0_nc_SKYLAKEX,
+  cgemm_small_kernel_b0_tn_SKYLAKEX, cgemm_small_kernel_b0_tt_SKYLAKEX, cgemm_small_kernel_b0_tr_SKYLAKEX, cgemm_small_kernel_b0_tc_SKYLAKEX,
+  cgemm_small_kernel_b0_rn_SKYLAKEX, cgemm_small_kernel_b0_rt_SKYLAKEX, cgemm_small_kernel_b0_rr_SKYLAKEX, cgemm_small_kernel_b0_rc_SKYLAKEX,
+  cgemm_small_kernel_b0_cn_SKYLAKEX, cgemm_small_kernel_b0_ct_SKYLAKEX, cgemm_small_kernel_b0_cr_SKYLAKEX, cgemm_small_kernel_b0_cc_SKYLAKEX,
+#endif
+
   ctrsm_kernel_LN_SKYLAKEX, ctrsm_kernel_LT_SKYLAKEX, ctrsm_kernel_LR_SKYLAKEX, ctrsm_kernel_LC_SKYLAKEX,
   ctrsm_kernel_RN_SKYLAKEX, ctrsm_kernel_RT_SKYLAKEX, ctrsm_kernel_RR_SKYLAKEX, ctrsm_kernel_RC_SKYLAKEX,
 
@@ -533,6 +563,18 @@ gotoblas_t TABLE_NAME = {
 #endif
   zgemm_oncopy_SKYLAKEX, zgemm_otcopy_SKYLAKEX,
 
+#ifdef SMALL_MATRIX_OPT
+  zgemm_small_matrix_permit_SKYLAKEX,
+  zgemm_small_kernel_nn_SKYLAKEX, zgemm_small_kernel_nt_SKYLAKEX, zgemm_small_kernel_nr_SKYLAKEX, zgemm_small_kernel_nc_SKYLAKEX,
+  zgemm_small_kernel_tn_SKYLAKEX, zgemm_small_kernel_tt_SKYLAKEX, zgemm_small_kernel_tr_SKYLAKEX, zgemm_small_kernel_tc_SKYLAKEX,
+  zgemm_small_kernel_rn_SKYLAKEX, zgemm_small_kernel_rt_SKYLAKEX, zgemm_small_kernel_rr_SKYLAKEX, zgemm_small_kernel_rc_SKYLAKEX,
+  zgemm_small_kernel_cn_SKYLAKEX, zgemm_small_kernel_ct_SKYLAKEX, zgemm_small_kernel_cr_SKYLAKEX, zgemm_small_kernel_cc_SKYLAKEX,
+  zgemm_small_kernel_b0_nn_SKYLAKEX, zgemm_small_kernel_b0_nt_SKYLAKEX, zgemm_small_kernel_b0_nr_SKYLAKEX, zgemm_small_kernel_b0_nc_SKYLAKEX,
+  zgemm_small_kernel_b0_tn_SKYLAKEX, zgemm_small_kernel_b0_tt_SKYLAKEX, zgemm_small_kernel_b0_tr_SKYLAKEX, zgemm_small_kernel_b0_tc_SKYLAKEX,
+  zgemm_small_kernel_b0_rn_SKYLAKEX, zgemm_small_kernel_b0_rt_SKYLAKEX, zgemm_small_kernel_b0_rr_SKYLAKEX, zgemm_small_kernel_b0_rc_SKYLAKEX,
+  zgemm_small_kernel_b0_cn_SKYLAKEX, zgemm_small_kernel_b0_ct_SKYLAKEX, zgemm_small_kernel_b0_cr_SKYLAKEX, zgemm_small_kernel_b0_cc_SKYLAKEX,
+#endif
+
   ztrsm_kernel_LN_SKYLAKEX, ztrsm_kernel_LT_SKYLAKEX, ztrsm_kernel_LR_SKYLAKEX, ztrsm_kernel_LC_SKYLAKEX,
   ztrsm_kernel_RN_SKYLAKEX, ztrsm_kernel_RT_SKYLAKEX, ztrsm_kernel_RR_SKYLAKEX, ztrsm_kernel_RC_SKYLAKEX,
 
