@@ -112,6 +112,11 @@ gotoblas_t TABLE_NAME = {
 #else
   NULL,NULL,
 #endif
+#ifdef SMALL_MATRIX_OPT
+  sbgemm_small_matrix_permit_STEAMROLLER,
+  sbgemm_small_kernel_nn_STEAMROLLER, sbgemm_small_kernel_nt_STEAMROLLER, sbgemm_small_kernel_tn_STEAMROLLER, sbgemm_small_kernel_tt_STEAMROLLER,
+  sbgemm_small_kernel_b0_nn_STEAMROLLER, sbgemm_small_kernel_b0_nt_STEAMROLLER, sbgemm_small_kernel_b0_tn_STEAMROLLER, sbgemm_small_kernel_b0_tt_STEAMROLLER,
+#endif
 #endif
 
 #if ( BUILD_SINGLE==1) || (BUILD_DOUBLE==1) || (BUILD_COMPLEX==1) || (BUILD_COMPLEX16==1)
@@ -171,6 +176,14 @@ gotoblas_t TABLE_NAME = {
   sgemm_oncopy_STEAMROLLER, sgemm_otcopy_STEAMROLLER,
 #endif
 
+#if BUILD_SINGLE == 1
+#ifdef SMALL_MATRIX_OPT
+  sgemm_small_matrix_permit_STEAMROLLER,
+  sgemm_small_kernel_nn_STEAMROLLER, sgemm_small_kernel_nt_STEAMROLLER, sgemm_small_kernel_tn_STEAMROLLER, sgemm_small_kernel_tt_STEAMROLLER,
+  sgemm_small_kernel_b0_nn_STEAMROLLER, sgemm_small_kernel_b0_nt_STEAMROLLER, sgemm_small_kernel_b0_tn_STEAMROLLER, sgemm_small_kernel_b0_tt_STEAMROLLER,
+#endif
+#endif
+
 #if (BUILD_SINGLE==1) || (BUILD_DOUBLE==1) 
   strsm_kernel_LN_STEAMROLLER, strsm_kernel_LT_STEAMROLLER, strsm_kernel_RN_STEAMROLLER, strsm_kernel_RT_STEAMROLLER,
 #if SGEMM_DEFAULT_UNROLL_M != SGEMM_DEFAULT_UNROLL_N
@@ -257,6 +270,11 @@ gotoblas_t TABLE_NAME = {
 #endif
 
 #if  (BUILD_DOUBLE==1)  
+#ifdef SMALL_MATRIX_OPT
+  dgemm_small_matrix_permit_STEAMROLLER,
+  dgemm_small_kernel_nn_STEAMROLLER, dgemm_small_kernel_nt_STEAMROLLER, dgemm_small_kernel_tn_STEAMROLLER, dgemm_small_kernel_tt_STEAMROLLER,
+  dgemm_small_kernel_b0_nn_STEAMROLLER, dgemm_small_kernel_b0_nt_STEAMROLLER, dgemm_small_kernel_b0_tn_STEAMROLLER, dgemm_small_kernel_b0_tt_STEAMROLLER,
+#endif
   dtrsm_kernel_LN_STEAMROLLER, dtrsm_kernel_LT_STEAMROLLER, dtrsm_kernel_RN_STEAMROLLER, dtrsm_kernel_RT_STEAMROLLER,
 #if DGEMM_DEFAULT_UNROLL_M != DGEMM_DEFAULT_UNROLL_N
   dtrsm_iunucopy_STEAMROLLER, dtrsm_iunncopy_STEAMROLLER, dtrsm_iutucopy_STEAMROLLER, dtrsm_iutncopy_STEAMROLLER,
@@ -389,6 +407,18 @@ gotoblas_t TABLE_NAME = {
 #endif
   cgemm_oncopy_STEAMROLLER, cgemm_otcopy_STEAMROLLER,
 
+#ifdef SMALL_MATRIX_OPT
+  cgemm_small_matrix_permit_STEAMROLLER,
+  cgemm_small_kernel_nn_STEAMROLLER, cgemm_small_kernel_nt_STEAMROLLER, cgemm_small_kernel_nr_STEAMROLLER, cgemm_small_kernel_nc_STEAMROLLER,
+  cgemm_small_kernel_tn_STEAMROLLER, cgemm_small_kernel_tt_STEAMROLLER, cgemm_small_kernel_tr_STEAMROLLER, cgemm_small_kernel_tc_STEAMROLLER,
+  cgemm_small_kernel_rn_STEAMROLLER, cgemm_small_kernel_rt_STEAMROLLER, cgemm_small_kernel_rr_STEAMROLLER, cgemm_small_kernel_rc_STEAMROLLER,
+  cgemm_small_kernel_cn_STEAMROLLER, cgemm_small_kernel_ct_STEAMROLLER, cgemm_small_kernel_cr_STEAMROLLER, cgemm_small_kernel_cc_STEAMROLLER,
+  cgemm_small_kernel_b0_nn_STEAMROLLER, cgemm_small_kernel_b0_nt_STEAMROLLER, cgemm_small_kernel_b0_nr_STEAMROLLER, cgemm_small_kernel_b0_nc_STEAMROLLER,
+  cgemm_small_kernel_b0_tn_STEAMROLLER, cgemm_small_kernel_b0_tt_STEAMROLLER, cgemm_small_kernel_b0_tr_STEAMROLLER, cgemm_small_kernel_b0_tc_STEAMROLLER,
+  cgemm_small_kernel_b0_rn_STEAMROLLER, cgemm_small_kernel_b0_rt_STEAMROLLER, cgemm_small_kernel_b0_rr_STEAMROLLER, cgemm_small_kernel_b0_rc_STEAMROLLER,
+  cgemm_small_kernel_b0_cn_STEAMROLLER, cgemm_small_kernel_b0_ct_STEAMROLLER, cgemm_small_kernel_b0_cr_STEAMROLLER, cgemm_small_kernel_b0_cc_STEAMROLLER,
+#endif
+
   ctrsm_kernel_LN_STEAMROLLER, ctrsm_kernel_LT_STEAMROLLER, ctrsm_kernel_LR_STEAMROLLER, ctrsm_kernel_LC_STEAMROLLER,
   ctrsm_kernel_RN_STEAMROLLER, ctrsm_kernel_RT_STEAMROLLER, ctrsm_kernel_RR_STEAMROLLER, ctrsm_kernel_RC_STEAMROLLER,
 
@@ -533,6 +563,18 @@ gotoblas_t TABLE_NAME = {
 #endif
   zgemm_oncopy_STEAMROLLER, zgemm_otcopy_STEAMROLLER,
 
+#ifdef SMALL_MATRIX_OPT
+  zgemm_small_matrix_permit_STEAMROLLER,
+  zgemm_small_kernel_nn_STEAMROLLER, zgemm_small_kernel_nt_STEAMROLLER, zgemm_small_kernel_nr_STEAMROLLER, zgemm_small_kernel_nc_STEAMROLLER,
+  zgemm_small_kernel_tn_STEAMROLLER, zgemm_small_kernel_tt_STEAMROLLER, zgemm_small_kernel_tr_STEAMROLLER, zgemm_small_kernel_tc_STEAMROLLER,
+  zgemm_small_kernel_rn_STEAMROLLER, zgemm_small_kernel_rt_STEAMROLLER, zgemm_small_kernel_rr_STEAMROLLER, zgemm_small_kernel_rc_STEAMROLLER,
+  zgemm_small_kernel_cn_STEAMROLLER, zgemm_small_kernel_ct_STEAMROLLER, zgemm_small_kernel_cr_STEAMROLLER, zgemm_small_kernel_cc_STEAMROLLER,
+  zgemm_small_kernel_b0_nn_STEAMROLLER, zgemm_small_kernel_b0_nt_STEAMROLLER, zgemm_small_kernel_b0_nr_STEAMROLLER, zgemm_small_kernel_b0_nc_STEAMROLLER,
+  zgemm_small_kernel_b0_tn_STEAMROLLER, zgemm_small_kernel_b0_tt_STEAMROLLER, zgemm_small_kernel_b0_tr_STEAMROLLER, zgemm_small_kernel_b0_tc_STEAMROLLER,
+  zgemm_small_kernel_b0_rn_STEAMROLLER, zgemm_small_kernel_b0_rt_STEAMROLLER, zgemm_small_kernel_b0_rr_STEAMROLLER, zgemm_small_kernel_b0_rc_STEAMROLLER,
+  zgemm_small_kernel_b0_cn_STEAMROLLER, zgemm_small_kernel_b0_ct_STEAMROLLER, zgemm_small_kernel_b0_cr_STEAMROLLER, zgemm_small_kernel_b0_cc_STEAMROLLER,
+#endif
+
   ztrsm_kernel_LN_STEAMROLLER, ztrsm_kernel_LT_STEAMROLLER, ztrsm_kernel_LR_STEAMROLLER, ztrsm_kernel_LC_STEAMROLLER,
   ztrsm_kernel_RN_STEAMROLLER, ztrsm_kernel_RT_STEAMROLLER, ztrsm_kernel_RR_STEAMROLLER, ztrsm_kernel_RC_STEAMROLLER,
 
